==> tboxsdk-0.0.1.tar.gz: tboxsdk-0.0.1/tests/test_tbox_completion.py <==
import os
import sys

CWD = os.path.dirname(os.path.abspath(__file__))
SDK_PATH = os.path.dirname(CWD)

sys.path.append(SDK_PATH)

from tbox_client.core.httpclient import HttpClientConfig
from tbox_client.tbox import TboxClient


authorization = os.getenv("HTTP_CLIENT_AUTHORIZATION")
if authorization is None:
    raise Exception("env HTTP_CLIENT_AUTHORIZATION is not set")


tbox_client = TboxClient(authorization=authorization)
response = tbox_client.completion(appId="202505APvAlh00420022", inputs={"query": "今天杭州天气怎么样？"})
for chunk in response:
    print(f"--------------------------------------------------------")
    print(f"data: {chunk}")
    print(f"--------------------------------------------------------")


#--------------------------------------------------------
#data: {'entity': {'node_type': 'output', 'execute_id': '2', 'node_name': '结束', 'node_id': 'output_isn9lm'}, 'lane': 'mvz20luv', 'payload': {'extraParams': {}, 'mediaType': 'text', 'name': '回答', 'requestId': '7a03c482-955d-4861-83c5-59024629ed26', 'sessionId': '20250523U1OO28836351'}, 'type': 'header'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '今天'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '杭州'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '的'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '天气就像是江南水墨'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '画，温婉'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '又带着几分朦胧'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '美。如果要'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '具体点说的话，'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '记得带上把小'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '伞哦，可能'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '偶尔会有几滴'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '细雨来添'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '几分诗意呢！'}, 'type': 'chunk'}
#--------------------------------------------------------

==> tboxsdk-0.0.2.tar.gz: tboxsdk-0.0.2/tests/test_tbox_completion.py <==
import os
import sys

CWD = os.path.dirname(os.path.abspath(__file__))
SDK_PATH = os.path.dirname(CWD)

sys.path.append(SDK_PATH)

from tboxsdk.core.httpclient import HttpClientConfig
from tboxsdk.tbox import TboxClient


authorization = os.getenv("HTTP_CLIENT_AUTHORIZATION")
if authorization is None:
    raise Exception("env HTTP_CLIENT_AUTHORIZATION is not set")


tbox_client = TboxClient(authorization=authorization)
response = tbox_client.completion(appId="202505APvAlh00420022", inputs={"query": "今天杭州天气怎么样？"}, userId="1234567890")
for chunk in response:
    print(f"--------------------------------------------------------")
    print(f"data: {chunk}")
    print(f"--------------------------------------------------------")


#--------------------------------------------------------
#data: {'entity': {'node_type': 'output', 'execute_id': '2', 'node_name': '结束', 'node_id': 'output_isn9lm'}, 'lane': 'mvz20luv', 'payload': {'extraParams': {}, 'mediaType': 'text', 'name': '回答', 'requestId': '7a03c482-955d-4861-83c5-59024629ed26', 'sessionId': '20250523U1OO28836351'}, 'type': 'header'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '今天'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '杭州'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '的'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '天气就像是江南水墨'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '画，温婉'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '又带着几分朦胧'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '美。如果要'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '具体点说的话，'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '记得带上把小'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '伞哦，可能'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '偶尔会有几滴'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '细雨来添'}, 'type': 'chunk'}
#--------------------------------------------------------
#--------------------------------------------------------
#data: {'lane': 'mvz20luv', 'payload': {'text': '几分诗意呢！'}, 'type': 'chunk'}
#--------------------------------------------------------
